Struct amazon_sp_fulfillment_outbound::models::update_fulfillment_order_request::UpdateFulfillmentOrderRequest
source · [−]pub struct UpdateFulfillmentOrderRequest {
pub marketplace_id: Option<String>,
pub displayable_order_id: Option<String>,
pub displayable_order_date: Option<String>,
pub displayable_order_comment: Option<String>,
pub shipping_speed_category: Option<ShippingSpeedCategory>,
pub destination_address: Option<Box<Address>>,
pub fulfillment_action: Option<FulfillmentAction>,
pub fulfillment_policy: Option<FulfillmentPolicy>,
pub ship_from_country_code: Option<String>,
pub notification_emails: Option<Vec<String>>,
pub feature_constraints: Option<Vec<FeatureSettings>>,
pub items: Option<Vec<UpdateFulfillmentOrderItem>>,
}Fields
marketplace_id: Option<String>The marketplace the fulfillment order is placed against.
displayable_order_id: Option<String>A fulfillment order identifier that the seller creates. This value displays as the order identifier in recipient-facing materials such as the outbound shipment packing slip. The value of DisplayableOrderId should match the order identifier that the seller provides to the recipient. The seller can use the SellerFulfillmentOrderId for this value or they can specify an alternate value if they want the recipient to reference an alternate order identifier.
displayable_order_date: Option<String>displayable_order_comment: Option<String>Order-specific text that appears in recipient-facing materials such as the outbound shipment packing slip.
shipping_speed_category: Option<ShippingSpeedCategory>destination_address: Option<Box<Address>>fulfillment_action: Option<FulfillmentAction>fulfillment_policy: Option<FulfillmentPolicy>ship_from_country_code: Option<String>The two-character country code for the country from which the fulfillment order ships. Must be in ISO 3166-1 alpha-2 format.
notification_emails: Option<Vec<String>>A list of email addresses that the seller provides that are used by Amazon to send ship-complete notifications to recipients on behalf of the seller.
feature_constraints: Option<Vec<FeatureSettings>>A list of features and their fulfillment policies to apply to the order.
items: Option<Vec<UpdateFulfillmentOrderItem>>An array of fulfillment order item information for updating a fulfillment order.
Implementations